from ..lib import command

switcher = {
        1: "Homebrew",
        2: "Oh-my-zsh",
        3: "Xcode",
        4: "Development-setup",
        5: "Netdata"
    }

def run_macos():
    """Main Function"""
    
    print("You are running MacOS")
    command.print_choice(switcher)
    value = command.check_input()
    exit_value = command.run_input("macos", switcher, value)
    if exit_value == 0:
        run_macos()
    else: 
        quit()


from oli.lib.linux_process import run_process, run_process_no_log

def run():
    if run_process(['sh -c "$(curl -Ss https://my-netdata.io/kickstart.sh)"']) == 0:
        return 0
    else:
        return 1


import platform
import signal
import sys
from oli.macos import mac
from oli.linux import linux

def signal_handler(signal, frame):
    print("\nGracefully exiting")
    sys.exit(0)

def run_as_command():
    platform_name = platform.system()
    if platform_name == "Darwin":
        mac.run_macos()
    if platform_name == "Linux":
        linux.run_linux()

        

signal.signal(signal.SIGINT, signal_handler)

if __name__ == "__main__":
    run_as_command()




from oli.lib.linux_process import run_process
import os

def generateConfig(name, team, gpu):
    config = '<config> <user value="' + str(name) + '"/><team value="' + str(team) + '"/><passkey value=""/><smp value="true"/><gpu value="'+ str(gpu) + '"/><power value="full"/></config>'
    return config

def run():
    #sudo DEBIAN_FRONTEND=noninteractive apt-get install -y /home/stan/fahclient_7.4.4_amd64.deb
    name = str(input("\nWhat would you like your name to be ? Default Anonymous " ) or "Anonymous")
    team = int(input("\nWhat team would you like to join (int) ? Default 263124 ") or "263124")
    gpu = "false"
    if str(input("Would you like to use your gpu ? Default No (y/n)" ) or "No").lower().startswith("y"):
        gpu = "true"
    if run_process("sudo mkdir -p ~/folding") == 0:
        if run_process("sudo wget -N https://download.foldingathome.org/releases/public/release/fahclient/debian-testing-64bit/v7.4/fahclient_7.4.4-64bit-release.tar.bz2 -P ~/folding/") == 0:
            if run_process("sudo chown $USER:$USER ~/folding/") == 0:
                if run_process("tar jxf ~/folding/fahclient_7.4.4-64bit-release.tar.bz2 --strip-components=1 -C ~/folding/ ") == 0:
                    with open(os.path.expanduser("~/folding/config.xml"), 'w') as configFile:
                        configFile.write(generateConfig(name, team, gpu))
                        return 0
                            
    return 1
    # FAHClient



import subprocess
from oli.lib.command import bcolors
import sys

def run_process(command_execute):
    process = subprocess.Popen(command_execute, 
                           stdout=subprocess.PIPE,
                           stderr=subprocess.PIPE,
                           shell=True,
                           universal_newlines=True)
    
    while True:
        out = process.stdout.read(1)
        if out == '' and process.poll() != None:
            break
        if out != '':
            sys.stdout.write(out)
            sys.stdout.flush()
    return process.poll()


def run_process_no_log(command_execute):
    process = subprocess.Popen(command_execute, 
                           stdout=subprocess.PIPE,
                           shell=True,
                           universal_newlines=True)
    return_code_script = None
    while True:
        return_code = process.poll()
        if return_code is not None:
            return_code_script = return_code
            break
    return return_code_script



import importlib

class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

def installation_finished():
        input_user = str(input(bcolors.OKBLUE +"\nWould you like to install something else ?" +  bcolors.ENDC + " Default yes (y/n) " ) or "y")
        if input_user.lower().startswith('y'):
            return 0
        else:
            return 1
            


def run_input(package, switch, value):
    string_value = switch.get(value, "Invalid Value")
    if string_value != 'Invalid Value':
        mymodule = importlib.import_module("oli." + package + "." + string_value)
        return_code = mymodule.run()
        if return_code == 0:
            print(bcolors.OKGREEN + "Command Successfull" + bcolors.ENDC )
            
        else:
            print(bcolors.FAIL + "An error occured during the execution" + bcolors.ENDC)
            print("Please check the logs to see what was the cause and run the command again")
        return installation_finished()
    print("Invalid Value")
    return 0


def check_input():
    """Checks the type of the input and keeps asking if not an int """
    
    value = input(bcolors.OKBLUE + "What would you like to install ? " + bcolors.ENDC)
    while not value.isdigit():
        value = input(bcolors.OKBLUE +"What would you like to install ? (A number please) "+ bcolors.ENDC)
    return int(value)

    

def print_choice(switcher_value):
    """Prints all the available choices"""
    print("----------------------")
    for key in switcher_value:
        print(str(key) + " - " + str(switcher_value[key]))

    print("----------------------")




from oli.lib.linux_process import run_process, run_process_no_log
from oli.lib.command import bcolors

def run():

    if run_process(['brew install netdata']) == 0:
       
        if run_process(['brew services start netdata']) == 0:
            print(bcolors.OKGREEN + "You can access Netdata at http://localhost:19999" + bcolors.OKGREEN)
            return 0
        else :
            return 1
    else: 
        return 1


from ..lib import command

switcher = {
        1: "Netdata",
        2: "Folding@Home"
    }

def run_linux():
    """Main Function"""
    
    print("You are running a Linux Based Distribution")
    command.print_choice(switcher)
    value = command.check_input()
    exit_value = command.run_input("linux", switcher, value)
    if exit_value == 0:
        run_linux()
    else: 
        quit()


from oli.lib.linux_process import run_process, run_process_no_log
from oli.lib.command import bcolors
from .Homebrew import run as hbrun

def run_brew(name, command):
    if str(input("\nWould you like to install "+ name +" ? Default yes (y/n) " ) or "y").lower().startswith('y'):
        print(bcolors.OKBLUE + "Installing " + name + bcolors.ENDC)
        exit_code = run_process(["brew " + command])
        if exit_code != 0:
            print(bcolors.FAIL + "Error in the installation of " + name  + ", exit code: " + exit_code + bcolors.ENDC)
            quit()
        else:
            print(bcolors.OKGREEN + "Installation Successfull" + bcolors.ENDC)
    else: 
        print("Ok, not installing " + name)

def run():
    print(bcolors.HEADER + " Checking" + bcolors.ENDC)
    exit_code = run_process_no_log(['which brew'])
    
    if exit_code != 0:
        input_user = str(input(bcolors.OKBLUE +"\nWould you like to install brew ?" +  bcolors.ENDC + " Default yes (y/n) " ) or "y")
        if input_user.lower().startswith('y'):
            print(bcolors.OKBLUE + "Installing Homebrew" + bcolors.ENDC)
            exit_code = hbrun()
            if not exit_code:
                print(bcolors.FAIL + "Error in the installation of Homebrew" + bcolors.ENDC)
                return 1
    else:
        print(bcolors.OKGREEN + "Updating Brew" + bcolors.ENDC)
        exit_code = run_process(["brew update"])
        if exit_code != 0:
            return 1
    run_brew("git", "install git")
    run_brew("Google Chrome", "cask install google-chrome")
    run_brew("Google Chrome Canary", "cask install google-chrome-canary")
    run_brew("Firefox", "cask install firefox")
    run_brew("Firefox Developer Edition", "cask install firefox-developer-edition")
    run_brew("Visual Studio Code", "cask install visual-studio-code")
    run_brew("Visual Studio Code Insiders", "cask install visual-studio-code-insiders")
    run_brew("Intellij", "cask install intellij-idea")
    run_brew("Eclipse Java", "cask install eclipse-java")
    run_brew("Postman", "cask install postman")
    run_brew("Docker", "cask install docker")
    run_brew("Spectacle", "cask install spectacle")
    run_brew("Tree", " install tree")




# brew install git
# brew cask install google-chrome
# brew cask install google-chrome-canary
# brew cask install firefox
# brew cask install firefox-developer-edition
# brew cask install visual-studio-code
# brew cask install visual-studio-code-insiders
# brew cask install intellij-idea
# brew cask install eclipse-java
# brew cask install postman
# brew cask install docker
# brew cask install spectacle
# brew install tree